# Quantization

INT8 symmetric quantization utilities for efficient inference.

## Functions

::: rotalabs_accel.quantization.symmetric.quantize_symmetric

::: rotalabs_accel.quantization.symmetric.dequantize

::: rotalabs_accel.quantization.symmetric.quantize_weight_per_channel

::: rotalabs_accel.quantization.symmetric.calculate_quantization_error

## Classes

::: rotalabs_accel.quantization.symmetric.QuantizedLinear
